@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent
 version: 2.2.4.1
-id: persistent-2.2.4.1-263fc3840b78e27a8a6fefdb05730e03
-key: persi_Jw4E26iwxDeCcv571A8U44
+id: persistent-2.2.4.1-f7f5136d623755022a88522f150cf471
+key: persi_EaSwPIdgS2KCq9YpdsKmAw
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -35,9 +35,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-2.2.4.1
-hs-libraries: HSpersistent-2.2.4.1-Jw4E26iwxDeCcv571A8U44
+hs-libraries: HSpersistent-2.2.4.1-EaSwPIdgS2KCq9YpdsKmAw
 depends:
-    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -51,7 +51,7 @@ depends:
     http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
+    monad-logger-0.3.18-77245c726e2e1fb18d9b7ba72ab04e41
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
     path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
